Parser
======

.. automodule:: pyrotoolbox.parsers
    :members: parse, read_workbench, read_developertool, read_aquaphoxlogger, read_fireplate_workbench, read_fsgo2, read_fdo2_logger, read_developertool_directory

Examples
---------

.. toctree::
    Demo1
